@@ -17,7 +17,6 @@ from django.contrib.admin.options import (
     TO_FIELD_VAR, IS_POPUP_VAR,
     get_ul_class, csrf_protect_m,
 )
-import six
 from django.utils.html import escape
 from django.core.exceptions import PermissionDenied
 try:
@@ -170,11 +169,10 @@ class DocumentAdmin(BaseDocumentAdmin):
         self.log = not settings.DATABASES.get('default', {}).get(
             'ENGINE', 'django.db.backends.dummy'
         ).endswith('dummy')
-        self.change_list_template = 'admin/change_document_list.html'
 
 # XXX: add inline init somewhere
     def _get_inline_instances(self):
-        for f in six.itervalues(self.model._fields):
+        for f in self.model._fields.values():
             if not (isinstance(f, ListField) and isinstance(getattr(f, 'field', None), EmbeddedDocumentField)) and not isinstance(f, EmbeddedDocumentField):
                 continue
             # Should only reach here if there is an embedded document...
